@@ -305,7 +305,7 @@ def ablog_serve(website=None, port=8000, view=True, rebuild=False, patterns="*.r
         observer.start()
         try:
             if view:
-                (webbrowser.open_new_tab(f"http://127.0.0.1:{port}") and httpd.serve_forever())
+                webbrowser.open_new_tab(f"http://127.0.0.1:{port}") and httpd.serve_forever()
             else:
                 httpd.serve_forever()
         except KeyboardInterrupt:
@@ -314,7 +314,7 @@ def ablog_serve(website=None, port=8000, view=True, rebuild=False, patterns="*.r
 
     else:
         if view:
-            (webbrowser.open_new_tab(f"http://127.0.0.1:{port}") and httpd.serve_forever())
+            webbrowser.open_new_tab(f"http://127.0.0.1:{port}") and httpd.serve_forever()
         else:
             httpd.serve_forever()
 
