@@ -177,12 +177,11 @@ class CheckFrontMatter(SphinxTransform):
         if isinstance(tags, str):
             # myst_parser store front-matter field to TextNode in dict_to_fm_field_list.
             # like ["a", "b", "c"]
-            # remove [] and quote
-            try:
-                tags = eval(tags)
-                metadata["tags"] = ",".join(tags)
-            except Exception:
-                logging.warning(f"fail to eval tags: {tags}")
+            # remove [] and quotes
+            tags = tags.strip().lstrip("[").rstrip("]")
+            metadata["tags"] = ",".join(
+                [t.strip().lstrip('"').lstrip("'").rstrip('"').rstrip("'") for t in tags.split(",")]
+            )
         if docinfo.traverse(nodes.author):
             metadata["author"] = list(docinfo.traverse(nodes.author))[0].astext()
         # These two fields are special-cased in docutils
@@ -676,14 +675,10 @@ def generate_atom_feeds(app):
 
     blog = Blog(app)
 
-    url = blog.blog_baseurl
-    if not url:
+    base_url = blog.blog_baseurl
+    if not base_url:
         return
 
-    base_url = url
-    if len(blog.blog_languages) > 1:
-        base_url = os_path_join(url, app.config.language)
-
     feeds = [
         (
             blog.posts,
@@ -721,7 +716,7 @@ def generate_atom_feeds(app):
                             coll.path,
                             os.path.join(folder, feed_root + ".xml"),
                             blog.blog_title + " - " + header + " " + text_type(coll),
-                            os_path_join(url, coll.path, feed_root + ".xml"),
+                            os_path_join(base_url, coll.path, feed_root + ".xml"),
                             feed_templates,
                         )
                     )
@@ -735,7 +730,7 @@ def generate_atom_feeds(app):
         feed = FeedGenerator()
         feed.id(blog.blog_baseurl)
         feed.title(feed_title)
-        feed.link(href=url)
+        feed.link(href=base_url)
         feed.subtitle(blog.blog_feed_subtitle)
         feed.link(href=feed_url, rel="self")
         feed.language(app.config.language)
